@@ -4,6 +4,10 @@ from pybytom.wallet import Wallet as BTMWallet
 from pybytom.wallet.tools import get_public_key, get_program, get_address, indexes_to_path, path_to_indexes
 
 from .rpc import get_balance, account_create
+from ..config import bytom
+
+# Bytom configuration
+bytom = bytom()
 
 
 # Bytom Wallet.
@@ -11,19 +15,19 @@ class Wallet:
     """
     Bytom Wallet class.
 
-    :param network: bytom network, defaults to testnet.
+    :param network: Bytom network, defaults to testnet.
     :type network: str
-    :param account: bytom derivation account, defaults to 1.
+    :param account: Bytom derivation account, defaults to 1.
     :type account: int
-    :param change: bytom derivation change, defaults to False.
+    :param change: Bytom derivation change, defaults to False.
     :type change: bool
-    :param address: bytom derivation address, defaults to 1.
+    :param address: Bytom derivation address, defaults to 1.
     :type address: int
-    :param path: bytom derivation path, defaults to None.
+    :param path: Bytom derivation path, defaults to None.
     :type path: str
-    :param indexes: bytom derivation indexes, defaults to None.
+    :param indexes: Bytom derivation indexes, defaults to None.
     :type indexes: list
-    :returns:  Wallet -- bytom wallet instance.
+    :returns:  Wallet -- Bytom wallet instance.
 
     .. note::
         Bytom has only three networks, ``mainnet``, ``solonet`` and ``testnet``.
@@ -62,11 +66,11 @@ class Wallet:
     # Bytom wallet from entropy
     def from_entropy(self, entropy):
         """
-        Initiate bytom wallet from entropy.
+        Initiate Bytom wallet from entropy.
 
         :param entropy: Bytom wallet entropy.
         :type entropy: str.
-        :returns:  Wallet -- bytom wallet instance.
+        :returns:  Wallet -- Bytom wallet instance.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -88,11 +92,11 @@ class Wallet:
     # Bytom wallet from mnemonic
     def from_mnemonic(self, mnemonic):
         """
-        Initiate bytom wallet from mnemonic.
+        Initiate Bytom wallet from mnemonic.
 
         :param mnemonic: Bytom wallet mnemonic.
         :type mnemonic: str.
-        :returns:  Wallet -- bytom wallet instance.
+        :returns:  Wallet -- Bytom wallet instance.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -114,11 +118,11 @@ class Wallet:
     # Bytom wallet from seed
     def from_seed(self, seed):
         """
-        Initiate bytom wallet from seed.
+        Initiate Bytom wallet from seed.
 
         :param seed: Bytom wallet seed.
         :type seed: str.
-        :returns:  Wallet -- bytom wallet instance.
+        :returns:  Wallet -- Bytom wallet instance.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -140,11 +144,11 @@ class Wallet:
     # Bytom wallet from xprivate key
     def from_xprivate_key(self, xprivate_key):
         """
-        Initiate bytom wallet from xprivate key.
+        Initiate Bytom wallet from xprivate key.
 
         :param xprivate_key: Bytom wallet xprivate key.
         :type xprivate_key: str.
-        :returns:  Wallet -- bytom wallet instance.
+        :returns:  Wallet -- Bytom wallet instance.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -166,11 +170,11 @@ class Wallet:
     # Bytom wallet from xpublic key
     def from_xpublic_key(self, xpublic_key):
         """
-        Initiate bytom wallet from xpublic key.
+        Initiate Bytom wallet from xpublic key.
 
         :param xpublic_key: Bytom wallet xpublic key.
         :type xpublic_key: str.
-        :returns:  Wallet -- bytom wallet instance.
+        :returns:  Wallet -- Bytom wallet instance.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -179,7 +183,7 @@ class Wallet:
         """
 
         # Bytom wallet initialization.
-        bytom = BTMWallet()
+        Bytom = BTMWallet()
         self._xpublic_key = xpublic_key
         self._public_key = get_public_key(xpublic_key=self._xpublic_key, path=self.path())
         self._program = get_program(public_key=self._public_key)
@@ -190,11 +194,11 @@ class Wallet:
     # Bytom wallet from public key
     def from_public_key(self, public):
         """
-        Initiate bytom wallet from public key.
+        Initiate Bytom wallet from public key.
 
         :param public: Bytom wallet public key.
         :type public: str.
-        :returns:  Wallet -- bytom wallet instance.
+        :returns:  Wallet -- Bytom wallet instance.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -203,7 +207,7 @@ class Wallet:
         """
 
         # Bytom wallet initialization.
-        bytom = BTMWallet()
+        Bytom = BTMWallet()
         self._public_key = public
         self._program = get_program(
             public_key=self._public_key)
@@ -233,9 +237,9 @@ class Wallet:
     # Getting path
     def path(self):
         """
-        Get bytom wallet derivation path.
+        Get Bytom wallet derivation path.
 
-        :return: str -- bytom derivation path.
+        :return: str -- Bytom derivation path.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet", change=True, address=3)
@@ -260,9 +264,9 @@ class Wallet:
     # Getting seed
     def seed(self):
         """
-        Get bytom wallet seed.
+        Get Bytom wallet seed.
 
-        :return: str -- bytom seed.
+        :return: str -- Bytom seed.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -278,9 +282,9 @@ class Wallet:
     # Getting path derivation indexes
     def indexes(self):
         """
-        Get bytom wallet derivation indexes.
+        Get Bytom wallet derivation indexes.
 
-        :return: list -- bytom derivation indexes.
+        :return: list -- Bytom derivation indexes.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -294,9 +298,9 @@ class Wallet:
     # Getting xprivate key
     def xprivate_key(self):
         """
-        Get bytom wallet xprivate key.
+        Get Bytom wallet xprivate key.
 
-        :return: str -- bytom xprivate key.
+        :return: str -- Bytom xprivate key.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -312,9 +316,9 @@ class Wallet:
     # Getting xpublic key
     def xpublic_key(self):
         """
-        Get bytom wallet xpublic key.
+        Get Bytom wallet xpublic key.
 
-        :return: str -- bytom xpublic key.
+        :return: str -- Bytom xpublic key.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -330,9 +334,9 @@ class Wallet:
     # Getting expand xprivate key
     def expand_xprivate_key(self):
         """
-        Get bytom wallet expand xprivate key.
+        Get Bytom wallet expand xprivate key.
 
-        :return: str -- bytom expand xprivate key.
+        :return: str -- Bytom expand xprivate key.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -348,9 +352,9 @@ class Wallet:
     # Getting private key
     def private_key(self):
         """
-        Get bytom wallet private key.
+        Get Bytom wallet private key.
 
-        :return: str -- bytom private key.
+        :return: str -- Bytom private key.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -364,9 +368,9 @@ class Wallet:
     # Getting public key
     def public_key(self):
         """
-        Get bytom wallet public key.
+        Get Bytom wallet public key.
 
-        :return: str -- bytom public key.
+        :return: str -- Bytom public key.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -380,9 +384,9 @@ class Wallet:
     # Getting control program
     def program(self):
         """
-        Get bytom wallet control program.
+        Get Bytom wallet control program.
 
-        :return: str -- bytom control program.
+        :return: str -- Bytom control program.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -396,9 +400,9 @@ class Wallet:
     # Getting address
     def address(self):
         """
-        Get bytom wallet address.
+        Get Bytom wallet address.
 
-        :return: str -- bytom address.
+        :return: str -- Bytom address.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -412,9 +416,9 @@ class Wallet:
     # Getting guid from blockcenter
     def guid(self):
         """
-        Get bytom wallet blockcenter guid.
+        Get Bytom wallet blockcenter guid.
 
-        :return: str -- bytom blockcenter guid.
+        :return: str -- Bytom blockcenter guid.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -429,11 +433,13 @@ class Wallet:
         return self._guid
 
     # Getting balance
-    def balance(self):
+    def balance(self, asset=bytom["BTM_asset"]):
         """
-        Get bytom wallet balance.
+        Get Bytom wallet balance.
 
-        :return: int -- bytom balance.
+        :param asset: Bytom asset id, defaults to BTM asset.
+        :type asset: str
+        :return: int -- Bytom balance.
 
         >>> from shuttle.providers.bytom.wallet import Wallet
         >>> wallet = Wallet(network="mainnet")
@@ -442,4 +448,4 @@ class Wallet:
         2450000000
         """
 
-        return get_balance(address=self.address(), network=self.network)
+        return get_balance(address=self.address(), asset=asset, network=self.network)
